/*
 * Created on 17-Jul-2003
 */
package utils;

import appia.protocols.common.InetWithPort;

/**
 * @author nuno
 */
public class ProcessSet {

	SampleProcess[] processes;
	private int self;
	
	/**
	 * Constructor of the class.
	 * @param n number of processes.
	 */
	public ProcessSet(int n){
		processes = new SampleProcess[n];
	}

	/**
	 * Gets an array with all processes.
	 * @return
	 */
	public SampleProcess[] getAllProcesses(){
		return processes;
	}

	/**
	 * Gets the number of processes.
	 * @return
	 */
	public int getSize(){
		return processes.length;
	}

	/**
	 * Gets the rank of the specified process.
	 * @param addr the address of the process
	 * @return the rank of the process
	 */
	public int getRank(InetWithPort addr){
		for(int i=0; i<processes.length; i++){
			if(processes[i].getInetWithPort().equals(addr))
				return i; 
		}
		return -1;
	}

	/**
	 * Adds a process into the process set.
	 * @param process the process to add.
	 * @param i the rank of the process.
	 */
	public void addProcess(SampleProcess process, int i){
		processes[i] = process;
		if(process.isSelf())
			self = i;
	}

	/**
	 * Sets the process specified by the rank "proc" to correct or crashed.
	 * @param proc the process rank.
	 * @param correct true if the process is correct, false if the process crashed.
	 */
	public void setCorrect(int proc, boolean correct){
		processes[proc].setCorrect(correct);
	}
	
	/**
	 * Gets the process with rank "i"
	 * @param i the process rank
	 * @return the process
	 */
	public SampleProcess getProcess(int i){
		return processes[i];
	}

	/**
	 * Gets the process with address "addr".
	 * @param addr the process address
	 * @return the process.
	 */
	public SampleProcess getProcess(InetWithPort addr){
		int i = getRank(addr);
		if(i == -1)
			return null;
		else
			return processes[i];
	}
	
	/**
	 * Gets the self rank.
	 * @return
	 */
	public int getSelfRank() {
		return self;
	}

	/**
	 * Gets the self process.
	 * @return
	 */
	public SampleProcess getSelfProcess(){
		return processes[self];
	}

	/**
	 * Clones the process set.
	 * @return a clone of the process set.
	 */
	public ProcessSet cloneProcessSet(){
		ProcessSet set = new ProcessSet(getSize());
		SampleProcess[] procs = getAllProcesses();
		for (int i=0; i<procs.length; i++)
			set.addProcess(procs[i].cloneProcess(),i);
		set.self = self;
		return set;
	}

}
